@@ -9,7 +9,7 @@ TEST_CASE("register_drop", "[registry]")
     spdlog::create<spdlog::sinks::null_sink_mt>(tested_logger_name);
     REQUIRE(spdlog::get(tested_logger_name) != nullptr);
     // Throw if registring existing name
-    REQUIRE_THROWS_AS(spdlog::create<spdlog::sinks::null_sink_mt>(tested_logger_name), spdlog::spdlog_ex);
+    REQUIRE_THROWS_AS(spdlog::create<spdlog::sinks::null_sink_mt>(tested_logger_name), const spdlog::spdlog_ex&);
 }
 
 TEST_CASE("explicit register"
@@ -20,7 +20,7 @@ TEST_CASE("explicit register"
     spdlog::register_logger(logger);
     REQUIRE(spdlog::get(tested_logger_name) != nullptr);
     // Throw if registring existing name
-    REQUIRE_THROWS_AS(spdlog::create<spdlog::sinks::null_sink_mt>(tested_logger_name), spdlog::spdlog_ex);
+    REQUIRE_THROWS_AS(spdlog::create<spdlog::sinks::null_sink_mt>(tested_logger_name), const spdlog::spdlog_ex&);
 }
 
 TEST_CASE("apply_all"
@@ -33,7 +33,7 @@ TEST_CASE("apply_all"
     spdlog::register_logger(logger2);
 
     int counter = 0;
-    spdlog::apply_all([&counter](std::shared_ptr<spdlog::logger> l) { counter++; });
+    spdlog::apply_all([&counter](std::shared_ptr<spdlog::logger>) { counter++; });
     REQUIRE(counter == 2);
 
     counter = 0;
